<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Brugerhåndtering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Tilføj en ny bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Tilføj brugerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Indtast adgangskoden igen til den nye bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>bekræft adgangskode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Brugernavn til den nye bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Brugerens loginnavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Indtast brugernavn til den nye bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>brugernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Adgangskode til den nye bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Brugerens adgangskode:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Indtast adgangskode til den nye bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>adgangskode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Bekræft adgangskode til bruger:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Slet brugerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Vælg bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Vælg bruger som skal slettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Bruger som skal slettes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Slet også brugerens hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Slet brugerens hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Omdøb brugerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Vælg bruger som skal redigeres:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nye brugernavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Skift brugerens adgangskode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>ny adgangskode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Bekræft ny adgangskode:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>bekræft ny adgangskode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Adgangskode for ny bruger:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Reparer en brugerkonfiguration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Rediger brugerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Vælg bruger til reparation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Bruger som skal ændres:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Gendan standarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Gendan browserkonfiguration til MX-standarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla-konfigurationer (Iceweasel eller Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Gendan gruppemedlemsskaber til MX-standarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Gruppemedlemsskaber</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Skift indstillinger for automatisk indlogning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Automatisk indlogning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Kræv adgangskode for at logge ind</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Kopiér/synkroniser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Kopiér mellem skriveborde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Vælg skrivebord for at kopiere fra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Vælg for kun at kopiere filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Kopiér kun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Vælg skrivebord skal der skal kopieres til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Kopiér til:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Kopiér fra:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Vælg at kopiere og så slette forskellene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Synkroniser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Vælg at kopiere/synkronisere delte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Delt mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Vælg at kopiere/synkronisere hele hjem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Hele hjem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Vælg at kopiere/synkronisere browserkonfigurationen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla-konfigurationer (Firefox eller Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Vælg at kopiere/synkronisere dokumenter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Dokumenter-mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Hvad der skal kopieres/synkroniseres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Forløb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Status på ændringerne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Forløb på ændringerne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Tilføj/fjern grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Tilføj gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Gruppenavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>gruppenavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Slet gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Gruppe som skal slettes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Gruppemedlemsskab</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Gruppernes bruger tilhører (skift grupperne ved at vælge/fravælge de tilhørende bokse):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Dobbelttjek venligst dine valg inden de anvendes, tildeling af forkerte gruppemedlemsskaber kan ødelægge systemet. Brug Reparer-fanebladet til at gendanne de originale medlemsskaber hvis du lavede en fejl.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Anvend ændringer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Annuller ændringer og afslut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="617"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="932"/>
        <source>none</source>
        <translation>ingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Brugerkonfigurationen repareres. Luk venligst alle andre programmer nu. Når du er færdig, så log ud og genstart. Er du sikker på, at du vil reparere nu?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation>Valgmuligheder for automatisk indlogning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Automatisk indlogning er blevet deaktiveret for &apos;%1&apos;-kontoen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Automatisk indlogning er blevet aktiveret for &apos;%1&apos;-kontoen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Du skal angive en &apos;kopiér til&apos;-destination. Du kan ikke kopiere til skrivebordet som du er logget ind til.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Luk alle andre programmer inden kopiering. Sørg for at kopien til destinationen er stor nok til at indeholde de filer du kopierer. Kopiering mellem skriveborde kan overskrive eller slette dine filer eller præferencer på destinationens skrivebord. Er du sikker på, at du vil fortsætte?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Synchronizing desktop...</source>
        <translation>Synkroniserer skrivebord...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Copying desktop...</source>
        <translation>Kopierer skrivebord...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Brugernavnet skal være mindst 2 tegn langt. Vælg venligst et længere navn inden du fortsætter.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Brugernavnet skal være små bogstaver og det
må ikke indeholde specialtegn eller mellemrum.
Vælg venligst et andet navn inden du fortsætter.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Beklager, navnet er allerede i brug. Indtast venligst et andet navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Indtastede adgangskoder er ikke ens. Prøv venligst igen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Adgangskoden skal være mindst 2 tegn langt. Vælg venligst en længere adgangskode inden du fortsætter.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>The user was added ok.</source>
        <translation>Brugeren blev tilføjet ok.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Failed to add the user.</source>
        <translation>Kunne ikke tilføje brugeren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Password successfully changed.</source>
        <translation>Adgangskoden blev ændret.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Failed to change password.</source>
        <translation>Kunne ikke ændre adgangskode.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Handlingen kan ikke fortrydes. Er du sikker på, at du vil slette brugeren %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>The user has been deleted.</source>
        <translation>Brugeren er blevet slettet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Failed to delete the user.</source>
        <translation>Kunne ikke slette brugeren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Gruppenavnet skal være mindst 2 tegn langt. Vælg venligst et længere navn inden du fortsætter.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Gruppenavnet skal være små bogstaver og det
må ikke indeholde specialtegn eller mellemrum.
Vælg venligst et andet navn inden du fortsætter.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Beklager, gruppenavnet findes allerede. Indtast venligst et andet navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>The system group was added ok.</source>
        <translation>Systemgruppen blev tilføjet ok.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Failed to add the system group.</source>
        <translation>Kunne ikke tilføje systemgruppen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Handlingen kan ikke fortrydes. Er du sikker på, at du vil slette gruppen %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>The group has been deleted.</source>
        <translation>Gruppen er blevet slettet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Failed to delete the group.</source>
        <translation>Kunne ikke slette gruppen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>The changes have been applied.</source>
        <translation>Ændringerne er blevet anvendt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Failed to apply group changes</source>
        <translation>Kunne ikke anvende gruppeændringer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The selected user name is currently in use.</source>
        <translation>Det valgte brugernavn er i brug.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>For at omdøbe brugeren skal du logge ud og ind igen med en anden brugerkonto.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Beklager, navnet findes allerede på systemet. Indtast venligst et andet navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Kunne ikke omdøbe brugeren. Sørg venligst for at brugeren ikke er logget ind. Det kan være du skal genstarte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>The user was renamed.</source>
        <translation>Brugeren blev omdøbt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synkroniserer skrivebord...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Copying desktop...ok</source>
        <translation>Kopierer skrivebord...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synkroniserer skrivebord...mislykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Copying desktop...failed</source>
        <translation>Kopierer skrivebord...mislykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>browse...</source>
        <translation>gennemse...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Simpel brugerkonfiguration til MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="802"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Select folder to copy to</source>
        <translation>Vælg mappe som der skal kopieres til</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Du skal køre programmet som root.</translation>
    </message>
</context>
</TS>
